Crate irondash_message_channel

Crate irondash_message_channel 

Structs

AsyncMethodInvoker
EventSink
FinalizableHandle
FinalizableHandle can be used as payload in super::Value::FinalizableHandle. Will be received in Dart as instance of FinalizableHandle. When the Dart instance gets garbage collected, the finalizer closure specified in `FinalizableHandle::new will be invoked.
IsolateId
Type alias for isolate identifier
Late
Cell implementation that supports late initialization and can only be set once; Panics if data is accessed before set has been called or if set is called more than once.
MessageChannelBase
MethodCall
MethodCallReply
MethodInvoker
PlatformError
RegisteredAsyncMethodHandler
RegisteredEventChannel
RegisteredMethodHandler
ValueTupleList
Wrapper for Value tuple that ensures that the underyling list is sorted

Enums

DartObject
FunctionResult
MethodCallError
PostMessageError
SendMessageError
TryFromError
Value

Traits

AsyncMethodHandler
EventHandler
IntoPlatformResult
MessageChannelDelegate
MethodHandler

Functions

irondash_init_message_channel_context

Type Aliases

MessageChannel
PlatformResult